@@ -1,6 +1,6 @@
-const Gio = imports.gi.Gio;
-const GObject = imports.gi.GObject;
-const Polari = imports.gi.Polari;
+/* exported AccountsMonitor */
+
+const { Gio, GObject, Polari } = imports.gi;
 const Signals = imports.signals;
 const Tp = imports.gi.TelepathyGLib;
 
@@ -73,7 +73,7 @@ var AccountsMonitor = class {
     _onPrepared(am, res) {
         try {
             am.prepare_finish(res);
-        } catch(e) {
+        } catch (e) {
             this._app.release();
             return; // no point in carrying on
         }
@@ -101,8 +101,8 @@ var AccountsMonitor = class {
             this._app.hold();
             a.request_presence_async(presence, 'offline', '', (a, res) => {
                 try {
-                    a.request_presence_finish(result);
-                } catch(e) { }
+                    a.request_presence_finish(res);
+                } catch (e) { }
                 this._app.release();
             });
         });
@@ -174,8 +174,7 @@ const PolariAccount = GObject.registerClass({
         visible: GObject.ParamSpec.boolean('visible',
                                            'visible',
                                            'visible',
-                                           GObject.ParamFlags.READWRITE |
-                                           GObject.ParamFlags.EXPLICIT_NOTIFY,
+                                           GObject.ParamFlags.READWRITE,
                                            true)
     }
 }, class PolariAccount extends Tp.Account {
