@@ -1,27 +1,24 @@
-const Gdk = imports.gi.Gdk;
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
-const Polari = imports.gi.Polari;
+/* exported Application */
+
+const { Gdk, Gio, GLib, GObject, Gtk, Polari } = imports.gi;
 const Tp = imports.gi.TelepathyGLib;
 
-const {AccountsMonitor} = imports.accountsMonitor;
+const { AccountsMonitor } = imports.accountsMonitor;
 const AppNotifications = imports.appNotifications;
 const Connections = imports.connections;
-const {InitialSetupWindow} = imports.initialSetup;
-const {MainWindow} = imports.mainWindow;
-const {NetworksManager} = imports.networksManager;
-const {PasteManager} = imports.pasteManager;
-const {RoomManager} = imports.roomManager;
-const {ServerRoomManager} = imports.serverRoomManager;
-const {TelepathyClient} = imports.telepathyClient;
-const {UserStatusMonitor} = imports.userTracker;
+const { InitialSetupWindow } = imports.initialSetup;
+const { MainWindow } = imports.mainWindow;
+const { NetworksManager } = imports.networksManager;
+const { PasteManager } = imports.pasteManager;
+const { RoomManager } = imports.roomManager;
+const { ServerRoomManager } = imports.serverRoomManager;
+const { TelepathyClient } = imports.telepathyClient;
+const { UserStatusMonitor } = imports.userTracker;
 const Utils = imports.utils;
 
 const MAX_RETRIES = 3;
 
-const IRC_SCHEMA_REGEX = /^(irc?:\/\/)([\da-z\.-]+):?(\d+)?\/(?:%23)?([\w\.\+-]+)/i;
+const IRC_SCHEMA_REGEX = /^(irc?:\/\/)([\da-z.-]+):?(\d+)?\/(?:%23)?([\w.+-]+)/i;
 
 const AUTOSTART_DIR = GLib.get_user_config_dir() + '/autostart';
 const AUTOSTART_FILE = '/org.gnome.Polari.Autostart.desktop';
@@ -34,8 +31,7 @@ var Application = GObject.registerClass({
         super._init({ application_id: 'org.gnome.Polari',
                       flags: Gio.ApplicationFlags.HANDLES_OPEN });
 
-        GLib.set_application_name('Polari');
-        GLib.set_prgname('org.gnome.Polari');
+        GLib.set_prgname('polari');
         this._retryData = new Map();
         this._nickTrackData = new Map();
         this._demons = [];
@@ -45,6 +41,11 @@ var Application = GObject.registerClass({
         this.add_main_option('start-client', 0,
                              GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
                              _("Start Telepathy client"), null);
+        // Only included for --help output, the actual option is handled
+        // from C before handling over control to JS
+        this.add_main_option('debugger', 'd',
+                             GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
+                             _("Start in debug mode"), null);
         this.add_main_option('test-instance', 0,
                              GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
                              _("Allow running alongside another instance"), null);
@@ -58,7 +59,7 @@ var Application = GObject.registerClass({
 
             try {
                 this.register(null);
-            } catch(e) {
+            } catch (e) {
                 return 1;
             }
 
@@ -100,7 +101,7 @@ var Application = GObject.registerClass({
         try {
             proxy = Gio.DBusProxy.new_sync(conn, flags, null,
                                            name, opath, iface, null);
-        } catch(e) {}
+        } catch (e) {}
 
         return proxy != null && proxy.get_name_owner() != null;
     }
@@ -118,7 +119,7 @@ var Application = GObject.registerClass({
         try {
             proc.init(null);
             this._demons.push(proc);
-        } catch(e) {
+        } catch (e) {
             log('Failed to launch %s: %s'.format(command, e.message));
         }
     }
@@ -130,9 +131,9 @@ var Application = GObject.registerClass({
 
         let handled = false;
         let id = Gio.bus_watch_name(bus, name, flags, () => {
-                debug('Running as test instance alongside primary instance');
-                this.set_flags(this.flags | Gio.ApplicationFlags.NON_UNIQUE);
-                handled = true;
+            debug('Running as test instance alongside primary instance');
+            this.set_flags(this.flags | Gio.ApplicationFlags.NON_UNIQUE);
+            handled = true;
         }, () => {
             debug('No primary instance found, running normally');
             handled = true;
@@ -145,7 +146,7 @@ var Application = GObject.registerClass({
         Gio.bus_unwatch_name(id);
     }
 
-    vfunc_dbus_register(conn, path) {
+    vfunc_dbus_register(conn, _path) {
         if (!Utils.isFlatpakSandbox())
             return true;
 
@@ -168,7 +169,7 @@ var Application = GObject.registerClass({
         return true;
     }
 
-    vfunc_dbus_unregister(conn, path) {
+    vfunc_dbus_unregister(_conn, _path) {
         for (let proc of this._demons)
             proc.force_exit();
         this._demons = [];
@@ -177,6 +178,7 @@ var Application = GObject.registerClass({
     vfunc_startup() {
         super.vfunc_startup();
 
+        /* eslint-disable indent */
         let actionEntries = [
           { name: 'show-join-dialog',
             activate: this._onShowJoinDialog.bind(this),
@@ -242,10 +244,11 @@ var Application = GObject.registerClass({
           { name: 'nth-room',
             parameter_type: GLib.VariantType.new('i') },
           { name: 'next-pending-room',
-            accels: ['<Alt><Shift>Down', '<Primary><Shift>Page_Down']},
+            accels: ['<Alt><Shift>Down', '<Primary><Shift>Page_Down'] },
           { name: 'previous-pending-room',
-            accels: ['<Alt><Shift>Up', '<Primary><Shift>Page_Up']}
+            accels: ['<Alt><Shift>Up', '<Primary><Shift>Page_Up'] }
         ];
+        /* eslint-enable indent */
         actionEntries.forEach(actionEntry => {
             let props = {};
             ['name', 'state', 'parameter_type'].forEach(prop => {
@@ -307,11 +310,10 @@ var Application = GObject.registerClass({
 
         let provider = new Gtk.CssProvider();
         let uri = 'resource:///org/gnome/Polari/css/application.css';
-        let file = Gio.File.new_for_uri(uri);
         try {
             provider.load_from_file(Gio.File.new_for_uri(uri));
-        } catch(e) {
-            logError(e, "Failed to add application style");
+        } catch (e) {
+            logError(e, 'Failed to add application style');
         }
         Gtk.StyleContext.add_provider_for_screen(Gdk.Screen.get_default(),
                                                  provider,
@@ -323,7 +325,7 @@ var Application = GObject.registerClass({
 
         if (!this.active_window) {
             if (this._needsInitialSetup()) {
-                let setupDialog = new InitialSetupWindow({ application: this });
+                new InitialSetupWindow({ application: this });
                 this._windowRemovedId = this.connect('window-removed', () => {
                     this.disconnect(this._windowRemovedId);
                     this._windowRemovedId = 0;
@@ -399,13 +401,13 @@ var Application = GObject.registerClass({
 
             if (matches.length)
                 joinAction.activate(new GLib.Variant('(ssu)',
-                                [matches[0], '#' + room, time]));
+                                                     [matches[0], '#' + room, time]));
             else
                 this._createAccount(matchedId, server, port, a => {
                     if (a)
                         joinAction.activate(new GLib.Variant('(ssu)',
-                                            [a.get_object_path(),
-                                             '#' + room, time]));
+                                                             [a.get_object_path(),
+                                                              '#' + room, time]));
                 });
         });
     }
@@ -416,7 +418,7 @@ var Application = GObject.registerClass({
         try {
             [,, server, port, room] = uri.match(IRC_SCHEMA_REGEX);
             success = true;
-        } catch(e) {
+        } catch (e) {
             let label = _("Failed to open link");
             let n = new AppNotifications.MessageNotification(label,
                                                              'dialog-error-symbolic');
@@ -463,7 +465,9 @@ var Application = GObject.registerClass({
     _touchFile(file) {
         try {
             file.get_parent().make_directory_with_parents(null);
-        } catch(e if e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS)) {
+        } catch (e) {
+            if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
+                throw e;
             // not an error, carry on
         }
 
@@ -481,7 +485,7 @@ var Application = GObject.registerClass({
                                       '/polari/initial-setup-completed');
         try {
             this._touchFile(f);
-        } catch(e) {
+        } catch (e) {
             if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
                 return false; // initial setup has completed
             log('Failed to mark initial setup as completed: ' + e.message);
@@ -514,19 +518,19 @@ var Application = GObject.registerClass({
     }
 
     _maybePresent(time) {
-        let [present, ] = Tp.user_action_time_should_present(time);
+        let [present] = Tp.user_action_time_should_present(time);
 
         if (!this.active_window || present)
             this.activate();
     }
 
     _onJoinRoom(action, parameter) {
-        let [accountPath, channelName, time] = parameter.deep_unpack();
+        let [accountPath_, channelName_, time] = parameter.deep_unpack();
         this._maybePresent(time);
     }
 
     _onMessageUser(action, parameter) {
-        let [accountPath, contactName, message, time] = parameter.deep_unpack();
+        let [accountPath_, contactName_, msg_, time] = parameter.deep_unpack();
         this._maybePresent(time);
     }
 
@@ -660,8 +664,8 @@ var Application = GObject.registerClass({
 
             if (reason != Tp.ConnectionStatusReason.REQUESTED) {
                 let strReasons = Object.keys(Tp.ConnectionStatusReason);
-                debug('Account %s disconnected with reason %s'.format(
-                      account.display_name, strReasons[reason]));
+                debug('Account %s disconnected with reason %s'
+                    .format(account.display_name, strReasons[reason]));
 
                 // Connection failed, keep tp from retrying over and over
                 let presence = Tp.ConnectionPresenceType.OFFLINE;
@@ -713,8 +717,8 @@ var Application = GObject.registerClass({
             });
             n.connect('undo', () => {
                 account.set_enabled_async(true, (o, res) => {
-                  account.set_enabled_finish(res);
-                  account.visible = true;
+                    account.set_enabled_finish(res);
+                    account.visible = true;
                 });
             });
         });
@@ -725,7 +729,7 @@ var Application = GObject.registerClass({
         let account = this._accountsMonitor.lookupAccount(accountPath);
         let dialog = new Connections.ConnectionProperties(account);
         dialog.transient_for = this.active_window;
-        dialog.connect('response', (w, reponse) => {
+        dialog.connect('response', w => {
             w.destroy();
         });
         dialog.show();
@@ -734,7 +738,9 @@ var Application = GObject.registerClass({
     _createLink(file, target) {
         try {
             file.get_parent().make_directory_with_parents(null);
-        } catch(e if e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS)) {
+        } catch (e) {
+            if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
+                throw e;
             // not an error, carry on
         }
 
@@ -747,14 +753,14 @@ var Application = GObject.registerClass({
         if (this._settings.get_boolean('run-in-background'))
             try {
                 this._createLink(file, pkg.pkgdatadir + AUTOSTART_FILE);
-            } catch(e) {
+            } catch (e) {
                 if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
                     log('Failed to create autostart link: ' + e.message);
             }
         else
             try {
                 file.delete(null);
-            } catch(e) {
+            } catch (e) {
                 if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_FOUND))
                     log('Failed to remove autostart link: ' + e.message);
             }
