@@ -1,18 +1,13 @@
-const Gdk = imports.gi.Gdk;
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+/* exported ChatView */
+
+const { Gdk, Gio, GLib, GObject, Gtk, Pango, PangoCairo, Polari } = imports.gi;
 const Mainloop = imports.mainloop;
-const Pango = imports.gi.Pango;
-const PangoCairo = imports.gi.PangoCairo;
-const Polari = imports.gi.Polari;
 const Tp = imports.gi.TelepathyGLib;
 const Tpl = imports.gi.TelepathyLogger;
 
-const {DropTargetIface} = imports.pasteManager;
-const {UserPopover} = imports.userList;
-const {UserStatusMonitor} = imports.userTracker;
+const { DropTargetIface } = imports.pasteManager;
+const { UserPopover } = imports.userList;
+const { UserStatusMonitor } = imports.userTracker;
 const Utils = imports.utils;
 
 var MAX_NICK_CHARS = 8;
@@ -20,20 +15,24 @@ const IGNORE_STATUS_TIME = 5;
 
 const SCROLL_TIMEOUT = 100; // ms
 
-const TIMESTAMP_INTERVAL = 300; // seconds of inactivity after which to
-                                // insert a timestamp
+// seconds of inactivity after which to insert a timestamp
+const TIMESTAMP_INTERVAL = 300;
 
-const INACTIVITY_THRESHOLD = 300; // a threshold in seconds used to control
-                                  // the visibility of status messages
+// a threshold in seconds used to control
+// the visibility of status messages
+const INACTIVITY_THRESHOLD = 300;
 const STATUS_NOISE_MAXIMUM = 4;
 
-const NUM_INITIAL_LOG_EVENTS = 50; // number of log events to fetch on start
-const NUM_LOG_EVENTS = 10; // number of log events to fetch when requesting more
+// number of log events to fetch on start
+const NUM_INITIAL_LOG_EVENTS = 50;
+// number of log events to fetch when requesting more
+const NUM_LOG_EVENTS = 10;
 
 const MARGIN = 14;
-const NICK_SPACING = 14; // space after nicks, matching the following elements
-                         // of the nick button in the entry area:
-                         // 8px padding + 6px spacing
+// space after nicks, matching the following elements
+// of the nick button in the entry area:
+// 8px padding + 6px spacing
+const NICK_SPACING = 14;
 
 const NICKTAG_PREFIX = 'nick';
 
@@ -85,11 +84,11 @@ class TextView extends Gtk.TextView {
 
         let tags = iter.get_tags();
         let pixelsAbove = tags.reduce((prev, current) => {
-                return Math.max(prev, current.pixels_above_lines);
-            }, this.get_pixels_above_lines());
+            return Math.max(prev, current.pixels_above_lines);
+        }, this.get_pixels_above_lines());
         let pixelsBelow = tags.reduce((prev, current) => {
-                return Math.max(prev, current.pixels_below_lines);
-            }, this.get_pixels_below_lines());
+            return Math.max(prev, current.pixels_below_lines);
+        }, this.get_pixels_below_lines());
 
         let lineSpace = Math.floor((pixelsAbove + pixelsBelow) / 2);
         y = y - lineSpace + 0.5;
@@ -139,7 +138,7 @@ class TextView extends Gtk.TextView {
     }
 });
 
-var ButtonTag = GObject.registerClass({
+const ButtonTag = GObject.registerClass({
     Properties: {
         'hover': GObject.ParamSpec.boolean('hover',
                                            'hover',
@@ -172,7 +171,7 @@ var ButtonTag = GObject.registerClass({
         this.notify('hover');
     }
 
-    vfunc_event(object, event, iter) {
+    vfunc_event(object, event, _iter) {
         this._ensureGesture(object);
 
         if (this._gesture.handle_event(event) ||
@@ -209,7 +208,7 @@ var ButtonTag = GObject.registerClass({
     }
 });
 
-var HoverFilterTag = GObject.registerClass({
+const HoverFilterTag = GObject.registerClass({
     Properties: {
         'filtered-tag': GObject.ParamSpec.object('filtered-tag',
                                                  'filtered-tag',
@@ -396,15 +395,16 @@ var ChatView = GObject.registerClass({
         });
         this._onChannelChanged();
 
-        this._nickStatusChangedId = this._userTracker.watchRoomStatus(this._room,
-                                    null,
-                                    this._onNickStatusChanged.bind(this));
+        this._nickStatusChangedId =
+            this._userTracker.watchRoomStatus(this._room, null,
+                                              this._onNickStatusChanged.bind(this));
     }
 
     _createTags() {
         let buffer = this._view.get_buffer();
         let tagTable = buffer.get_tag_table();
         let tags = [
+            /* eslint-disable indent */
           { name: 'nick',
             left_margin: MARGIN,
             weight: Pango.Weight.BOLD },
@@ -432,6 +432,7 @@ var ChatView = GObject.registerClass({
           { name: 'loading',
             left_margin: MARGIN,
             justification: Gtk.Justification.CENTER }
+            /* eslint-enable indent */
         ];
         tags.forEach(tagProps => { tagTable.add(new Gtk.TextTag(tagProps)); });
     }
@@ -472,12 +473,14 @@ var ChatView = GObject.registerClass({
         let buffer = this._view.get_buffer();
         let tagTable = buffer.get_tag_table();
         let tags = [
+            /* eslint-disable indent */
           { name: 'status',
             foreground_rgba: dimColor },
           { name: 'timestamp',
             foreground_rgba: dimColor },
           { name: 'url',
             foreground_rgba: linkColor }
+            /* eslint-enable indent */
         ];
         tags.forEach(tagProps => {
             let tag = tagTable.lookup(tagProps.name);
@@ -489,7 +492,7 @@ var ChatView = GObject.registerClass({
         });
 
         tagTable.foreach(tag => {
-            if(!tag.name)
+            if (!tag.name)
                 return;
 
             let nickname = this._getNickFromTagName(tag.name);
@@ -541,7 +544,7 @@ var ChatView = GObject.registerClass({
 
     _createMessage(source) {
         if (source instanceof Tp.Message) {
-            let [text, ] = source.to_text();
+            let [text] = source.to_text();
             let [id, valid] = source.get_pending_message_id();
             return { nick: source.sender.alias,
                      text: text,
@@ -673,7 +676,7 @@ var ChatView = GObject.registerClass({
         if (hasDir && dir != Gdk.ScrollDirection.UP)
             return Gdk.EVENT_PROPAGATE;
 
-        let [hasDeltas, dx, dy] = event.get_scroll_deltas();
+        let [hasDeltas, dx_, dy] = event.get_scroll_deltas();
         if (hasDeltas && dy >= 0)
             return Gdk.EVENT_PROPAGATE;
 
@@ -867,7 +870,7 @@ var ChatView = GObject.registerClass({
         let rect = this._view.get_visible_rect();
         let buffer = this._view.get_buffer();
         for (let i = 0; i < pending.length; i++) {
-            let [id,] = pending[i].get_pending_message_id();
+            let [id] = pending[i].get_pending_message_id();
             let mark = this._pending.get(id);
             if (!mark) {
                 this._channel.ack_message_async(pending[i], null);
@@ -956,7 +959,7 @@ var ChatView = GObject.registerClass({
         let message =
             actor ? _("%s has been banned by %s").format(member.alias,
                                                          actor.alias)
-                  : _("%s has been banned").format(member.alias)
+                  : _("%s has been banned").format(member.alias);
         this._insertStatus(message, member.alias, 'left');
     }
 
@@ -980,7 +983,7 @@ var ChatView = GObject.registerClass({
         let nick = tpMessage.sender.alias;
         let nickTag = this._lookupTag('nick' + nick);
         if (!nickTag)
-           return;
+            return;
         nickTag._lastActivity = GLib.get_monotonic_time();
     }
 
@@ -1028,7 +1031,7 @@ var ChatView = GObject.registerClass({
             buffer.tag_table.add(groupTag);
 
             groupTag.bind_property('invisible', headerArrowTag, 'invisible',
-                                    GObject.BindingFlags.INVERT_BOOLEAN);
+                                   GObject.BindingFlags.INVERT_BOOLEAN);
 
             headerTag.connect('clicked', () => {
                 groupTag.invisible = !groupTag.invisible;
@@ -1127,10 +1130,10 @@ var ChatView = GObject.registerClass({
         let hasAmPm = date.format('%p') != '';
 
         if (clockFormat == '24h' || !hasAmPm) {
-            if(daysAgo < 1) { // today
+            if (daysAgo < 1) { // today
                 /* Translators: Time in 24h format */
                 format = _("%H\u2236%M");
-            } else if(daysAgo <2) { // yesterday
+            } else if (daysAgo < 2) { // yesterday
                 /* Translators: this is the word "Yesterday" followed by a
                  time string in 24h format. i.e. "Yesterday, 14:30" */
                 // xgettext:no-c-format
@@ -1154,10 +1157,10 @@ var ChatView = GObject.registerClass({
                 format = _("%B %d %Y, %H\u2236%M");
             }
         } else {
-            if(daysAgo < 1) { // today
+            if (daysAgo < 1) { // today
                 /* Translators: Time in 12h format */
                 format = _("%l\u2236%M %p");
-            } else if(daysAgo <2) { // yesterday
+            } else if (daysAgo < 2) { // yesterday
                 /* Translators: this is the word "Yesterday" followed by a
                  time string in 12h format. i.e. "Yesterday, 2:30 pm" */
                 // xgettext:no-c-format
@@ -1269,7 +1272,7 @@ var ChatView = GObject.registerClass({
 
         // mask identify passwords in private chats
         if (this._room.type == Tp.HandleType.CONTACT) {
-            let [isIdentify, command, username, password] =
+            let [isIdentify, command_, username_, password] =
                 Polari.util_match_identify_message(text);
 
             if (isIdentify)
@@ -1277,7 +1280,7 @@ var ChatView = GObject.registerClass({
         }
 
         let channels = Utils.findChannels(text, server);
-        let urls = Utils.findUrls(text).concat(channels).sort((u1,u2) => u1.pos - u2.pos);
+        let urls = Utils.findUrls(text).concat(channels).sort((u1, u2) => u1.pos - u2.pos);
         let pos = 0;
         for (let i = 0; i < urls.length; i++) {
             let url = urls[i];
@@ -1328,8 +1331,8 @@ var ChatView = GObject.registerClass({
         let event = Gtk.get_current_event();
         let [, eventX, eventY] = event.get_coords();
         let [x, y] = view.window_to_buffer_coords(Gtk.TextWindowType.WIDGET,
-                                                          eventX, eventY);
-        let [inside, start] = view.get_iter_at_location(x, y);
+                                                  eventX, eventY);
+        let [inside_, start] = view.get_iter_at_location(x, y);
         let end = start.copy();
 
         if (!start.starts_tag(tag))
