@@ -1,10 +1,10 @@
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+/* exported ConnectionProperties ConnectionDetails ConnectionsList */
+
+const { GLib, GObject, Gtk } = imports.gi;
 const Tp = imports.gi.TelepathyGLib;
 
-const {AccountsMonitor} = imports.accountsMonitor;
-const {NetworksManager} = imports.networksManager;
+const { AccountsMonitor } = imports.accountsMonitor;
+const { NetworksManager } = imports.networksManager;
 const Utils = imports.utils;
 
 const DEFAULT_PORT = 6667;
@@ -25,7 +25,7 @@ function getAccountParams(account) {
     params['port'] = params['port'] || params['use-ssl'] ? DEFAULT_SSL_PORT
                                                          : DEFAULT_PORT;
     return params;
-};
+}
 
 const ConnectionRow = GObject.registerClass(
 class ConnectionRow extends Gtk.ListBoxRow {
@@ -77,7 +77,7 @@ var ConnectionsList = GObject.registerClass({
                                                     false)
     },
     Signals: { 'account-created': { param_types: [Tp.Account.$gtype] },
-               'account-selected': {}}
+               'account-selected': {} }
 }, class ConnectionsList extends Gtk.ScrolledWindow {
     _init(params) {
         this._favoritesOnly = false;
@@ -102,10 +102,10 @@ var ConnectionsList = GObject.registerClass({
                                         orientation: Gtk.Orientation.VERTICAL,
                                         visible: true });
         placeholder.add(new Gtk.Image({ icon_name: 'edit-find-symbolic',
-                                        pixel_size : 115,
-                                        visible : true }));
-        placeholder.add(new Gtk.Label({ label : _("No results."),
-                                        visible : true}));
+                                        pixel_size: 115,
+                                        visible: true }));
+        placeholder.add(new Gtk.Label({ label: _("No results."),
+                                        visible: true }));
 
         placeholder.get_style_context().add_class('dim-label');
 
@@ -163,12 +163,6 @@ var ConnectionsList = GObject.registerClass({
             row.activate();
     }
 
-    activateSelected() {
-        let row = this._list.get_selected_row();
-        if (row)
-            row.activate();
-    }
-
     _filterRows(row) {
         let matchTerms = this._networksManager.getNetworkMatchTerms(row.id);
         return this._filterTerms.every(term => {
@@ -266,8 +260,8 @@ var ConnectionDetails = GObject.registerClass({
                                                            'has-service',
                                                            'has-service',
                                                            GObject.ParamFlags.READABLE,
-                                                           false)},
-    Signals: { 'account-created': { param_types: [Tp.Account.$gtype] }},
+                                                           false) },
+    Signals: { 'account-created': { param_types: [Tp.Account.$gtype] } },
 }, class ConnectionDetails extends Gtk.Grid {
     _init(params) {
         this._networksManager = NetworksManager.getDefault();
@@ -434,7 +428,7 @@ var ConnectionDetails = GObject.registerClass({
                                           display_name: params.name });
         req.set_enabled(true);
 
-        let [details,] = this._detailsFromParams(params, {});
+        let [details] = this._detailsFromParams(params, {});
 
         for (let prop in details)
             req.set_parameter(prop, details[prop]);
