@@ -1,18 +1,13 @@
-const Gdk = imports.gi.Gdk;
-const GdkPixbuf = imports.gi.GdkPixbuf;
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gspell = imports.gi.Gspell;
-const Gtk = imports.gi.Gtk;
+/* exported ChatEntry EntryArea NickPopover */
+
+const { Gdk, GdkPixbuf, Gio, GLib, GObject, Gspell, Gtk } = imports.gi;
 const Mainloop = imports.mainloop;
 const Tp = imports.gi.TelepathyGLib;
 
 const ChatView = imports.chatView;
-const {DropTargetIface} = imports.pasteManager;
-const {EmojiPicker} = imports.emojiPicker;
-const {IrcParser} = imports.ircParser;
-const {TabCompletion} = imports.tabCompletion;
+const { DropTargetIface } = imports.pasteManager;
+const { IrcParser } = imports.ircParser;
+const { TabCompletion } = imports.tabCompletion;
 
 const MAX_NICK_UPDATE_TIME = 5; /* s */
 const MAX_LINES = 5;
@@ -34,29 +29,17 @@ var ChatEntry = GObject.registerClass({
         return this.__checker;
     }
 
-    static get _emojiPicker() {
-        if (!this.__emojiPicker)
-            this.__emojiPicker = new EmojiPicker();
-        return this.__emojiPicker;
-    }
-
     _init(params) {
         super._init(params);
 
         DropTargetIface.addTargets(this, this);
 
-        this._emojiPickedId = 0;
-
-        this.connect('icon-press', this._showEmojiPicker.bind(this));
-        this.connect('unmap', () => {
-            if (this._emojiPickedId)
-                ChatEntry._emojiPicker.disconnect(this._emojiPickedId);
-            this._emojiPickedId = 0;
-        });
-
         let app = Gio.Application.get_default();
         let action = app.lookup_action('show-emoji-picker');
-        action.connect('activate', this._showEmojiPicker.bind(this));
+        action.connect('activate', () => {
+            if (this.is_sensitive() && this.get_mapped())
+                this.emit('insert-emoji');
+        });
 
         let buffer = Gspell.EntryBuffer.get_from_gtk_entry_buffer(this.buffer);
         buffer.set_spell_checker (ChatEntry._checker);
@@ -67,25 +50,6 @@ var ChatEntry = GObject.registerClass({
         this._useDefaultHandler = false;
     }
 
-    _showEmojiPicker() {
-        if (!this.is_sensitive() || !this.get_mapped())
-            return;
-
-        if (!this._emojiPickedId)
-            this._emojiPickedId = ChatEntry._emojiPicker.connect('emoji-picked',
-                (w, emoji) => {
-                    this.delete_selection();
-                    let pos = this.insert_text(emoji, -1, this.get_position());
-                    this.set_position(pos);
-                    this.grab_focus_without_selecting();
-                });
-
-        let rect = this.get_icon_area(Gtk.EntryIconPosition.SECONDARY);
-        ChatEntry._emojiPicker.set_relative_to(this);
-        ChatEntry._emojiPicker.set_pointing_to(rect);
-        ChatEntry._emojiPicker.popup();
-    }
-
     get can_drop() {
         return true;
     }
@@ -96,11 +60,11 @@ var ChatEntry = GObject.registerClass({
             // Disable GtkEntry's built-in drop target support
             return;
 
-         GObject.signal_stop_emission_by_name(this, 'drag-data-received');
+        GObject.signal_stop_emission_by_name(this, 'drag-data-received');
         super.vfunc_drag_data_received(context, x, y, data, info, time);
     }
 
-    vfunc_paste_clipboard(entry) {
+    vfunc_paste_clipboard() {
         if (!this.editable || this._useDefaultHandler) {
             super.vfunc_paste_clipboard();
             return;
@@ -146,8 +110,7 @@ var NickPopover = GObject.registerClass({
         nick: GObject.ParamSpec.string('nick',
                                        'nick',
                                        'nick',
-                                       GObject.ParamFlags.READWRITE |
-                                       GObject.ParamFlags.EXPLICIT_NOTIFY,
+                                       GObject.ParamFlags.READWRITE,
                                        '')
     },
     Signals: { 'nick-changed': {} }
@@ -424,7 +387,7 @@ var EntryArea = GObject.registerClass({
         let fileInfo = null;
         try {
             fileInfo = file.query_info_finish(res);
-        } catch(e) {
+        } catch (e) {
             return;
         }
 
@@ -453,7 +416,7 @@ var EntryArea = GObject.registerClass({
                 if (url)
                     this._chatEntry.emit('insert-at-cursor', url);
             });
-        } catch(e) {
+        } catch (e) {
             let type = typeof this._pasteContent;
             debug('Failed to paste content of type ' +
                   (type == 'object' ? this._pasteContent.toString() : type));
