@@ -1,7 +1,6 @@
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+/* exported InitialSetupWindow */
+
+const { Gio, GLib, GObject, Gtk } = imports.gi;
 
 const Utils = imports.utils;
 
