@@ -1,10 +1,11 @@
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
+/* exported IrcParser */
+
+const { Gio, GLib } = imports.gi;
 const Signals = imports.signals;
 const Tp = imports.gi.TelepathyGLib;
 
 const AppNotifications = imports.appNotifications;
-const {RoomManager} = imports.roomManager;
+const { RoomManager } = imports.roomManager;
 const Utils = imports.utils;
 
 const N_ = s => s;
@@ -87,7 +88,7 @@ var IrcParser = class {
                     output = this._createFeedbackUsage(command);
                 else
                     output = this._createFeedbackGrid(_("Known commands:"),
-                                                        Object.keys(knownCommands));
+                                                      Object.keys(knownCommands));
                 break;
             }
             case 'INVITE': {
@@ -102,7 +103,7 @@ var IrcParser = class {
                         let contact;
                         try {
                             contact = c.dup_contact_by_id_finish(res);
-                        } catch(e) {
+                        } catch (e) {
                             logError(e, 'Failed to get contact for ' + nick);
                             return;
                         }
@@ -125,9 +126,9 @@ var IrcParser = class {
                 let app = Gio.Application.get_default();
                 let action = app.lookup_action('join-room');
                 action.activate(GLib.Variant.new('(ssu)',
-                                                 [ account.get_object_path(),
-                                                   room,
-                                                   Utils.getTpEventTime() ]));
+                                                 [account.get_object_path(),
+                                                  room,
+                                                  Utils.getTpEventTime()]));
                 break;
             }
             case 'KICK': {
@@ -142,7 +143,7 @@ var IrcParser = class {
                         let contact;
                         try {
                             contact = c.dup_contact_by_id_finish(res);
-                        } catch(e) {
+                        } catch (e) {
                             logError(e, 'Failed to get contact for ' + nick);
                             return;
                         }
@@ -176,17 +177,17 @@ var IrcParser = class {
                 let app = Gio.Application.get_default();
                 let action = app.lookup_action('message-user');
                 action.activate(GLib.Variant.new('(sssu)',
-                                                 [ account.get_object_path(),
-                                                   nick,
-                                                   message,
-                                                   Tp.USER_ACTION_TIME_NOT_USER_ACTION ]));
+                                                 [account.get_object_path(),
+                                                  nick,
+                                                  message,
+                                                  Tp.USER_ACTION_TIME_NOT_USER_ACTION]));
                 break;
             }
             case 'NAMES': {
                 let channel = this._room.channel;
                 let members = channel.group_dup_members_contacts().map(m => m.alias);
                 output = this._createFeedbackGrid(_("Users on %s:").format(channel.identifier),
-                                                    members);
+                                                  members);
                 break;
             }
             case 'NICK': {
@@ -204,7 +205,7 @@ var IrcParser = class {
             }
             case 'PART':
             case 'CLOSE': {
-                let room = null;;
+                let room = null;
                 let name = argv[0];
                 if (name)
                     room = this._roomManager.lookupRoomByName(name, this._room.account);
@@ -232,10 +233,10 @@ var IrcParser = class {
                 let app = Gio.Application.get_default();
                 let action = app.lookup_action('message-user');
                 action.activate(GLib.Variant.new('(sssu)',
-                                                 [ account.get_object_path(),
-                                                   nick,
-                                                   '',
-                                                   Utils.getTpEventTime() ]));
+                                                 [account.get_object_path(),
+                                                  nick,
+                                                  '',
+                                                  Utils.getTpEventTime()]));
                 break;
             }
             case 'QUIT': {
@@ -245,7 +246,7 @@ var IrcParser = class {
                     (a, res) => {
                         try {
                             a.request_presence_finish(res);
-                        } catch(e) {
+                        } catch (e) {
                             logError(e, 'Failed to disconnect');
                         }
                     });
@@ -287,10 +288,10 @@ var IrcParser = class {
     _sendMessage(message) {
         this._room.channel.send_message_async(message, 0, (c, res) => {
             try {
-                 c.send_message_finish(res);
-            } catch(e) {
+                c.send_message_finish(res);
+            } catch (e) {
                 // TODO: propagate to user
-                logError(e, 'Failed to send message')
+                logError(e, 'Failed to send message');
             }
         });
     }
