@@ -1,10 +1,8 @@
-const Gdk = imports.gi.Gdk;
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+/* exported JoinDialog */
 
-const {AccountsMonitor} = imports.accountsMonitor;
+const { Gdk, Gio, GLib, GObject, Gtk } = imports.gi;
+
+const { AccountsMonitor } = imports.accountsMonitor;
 const Utils = imports.utils;
 
 const DialogPage = {
@@ -87,7 +85,7 @@ var JoinDialog = GObject.registerClass({
     }
 
     get _hasAccounts() {
-      return this._accounts.size > 0;
+        return this._accounts.size > 0;
     }
 
     _setupMainPage() {
@@ -151,7 +149,7 @@ var JoinDialog = GObject.registerClass({
         if (!account)
             return;
 
-       this._serverRoomList.setAccount(account);
+        this._serverRoomList.setAccount(account);
     }
 
     _onAccountCreated(w, account) {
@@ -172,9 +170,9 @@ var JoinDialog = GObject.registerClass({
             let app = Gio.Application.get_default();
             let action = app.lookup_action('join-room');
             action.activate(GLib.Variant.new('(ssu)',
-                                             [ account.get_object_path(),
-                                             room,
-                                             Utils.getTpEventTime() ]));
+                                             [account.get_object_path(),
+                                              room,
+                                              Utils.getTpEventTime()]));
         });
     }
 
@@ -192,7 +190,7 @@ var JoinDialog = GObject.registerClass({
         let activeRoom = this.transient_for ? this.transient_for.active_room
                                             : null;
         let activeIndex = 0;
-        if(activeRoom)
+        if (activeRoom)
             activeIndex = Math.max(names.indexOf(activeRoom.account.display_name), 0);
         this._connectionCombo.set_active(activeIndex);
     }
