@@ -1,16 +1,13 @@
-const Gdk = imports.gi.Gdk;
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+/* exported MainWindow FixedSizeFrame RoomList RoomStack UserList */
+
+const { Gdk, Gio, GLib, GObject, Gtk, Polari } = imports.gi;
 const Mainloop = imports.mainloop;
-const Polari = imports.gi.Polari;
 const Tp = imports.gi.TelepathyGLib;
 
-const {AccountsMonitor} = imports.accountsMonitor;
-const {JoinDialog} = imports.joinDialog;
+const { AccountsMonitor } = imports.accountsMonitor;
+const { JoinDialog } = imports.joinDialog;
 const RoomList = imports.roomList; // used in template
-const {RoomManager} = imports.roomManager;
+const { RoomManager } = imports.roomManager;
 const RoomStack = imports.roomStack; // used in template
 const UserList = imports.userList; // used in template
 const Utils = imports.utils;
@@ -139,6 +136,8 @@ var MainWindow = GObject.registerClass({
 
         if (app.isTestInstance)
             this.get_style_context().add_class('test-instance');
+        if (GLib.get_application_name().toLowerCase().includes('snapshot'))
+            this.get_style_context().add_class('snapshot');
 
         // command output notifications should not pop up over
         // the input area, but appear to emerge from it, so
@@ -224,12 +223,12 @@ var MainWindow = GObject.registerClass({
         this._isMaximized = (state & Gdk.WindowState.MAXIMIZED) != 0;
     }
 
-    _onSizeAllocate(widget, allocation) {
+    _onSizeAllocate() {
         if (!this._isFullscreen && !this._isMaximized)
             this._currentSize = this.get_size();
     }
 
-    _onDestroy(widget) {
+    _onDestroy() {
         this._settings.set_boolean ('window-maximized', this._isMaximized);
         this._settings.set_value('window-size',
                                  GLib.Variant.new('ai', this._currentSize));
@@ -252,7 +251,9 @@ var MainWindow = GObject.registerClass({
     _touchFile(file) {
         try {
             file.get_parent().make_directory_with_parents(null);
-        } catch(e if e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS)) {
+        } catch (e) {
+            if (!e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
+                throw e;
             // not an error, carry on
         }
 
@@ -265,7 +266,7 @@ var MainWindow = GObject.registerClass({
                                       '/polari/close-confirmation-shown');
         try {
             this._touchFile(f);
-        } catch(e) {
+        } catch (e) {
             if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.EXISTS))
                 return Gdk.EVENT_PROPAGATE; // the dialog has been shown
             log('Failed to mark confirmation dialog as shown: ' + e.message);
@@ -275,7 +276,7 @@ var MainWindow = GObject.registerClass({
         return Gdk.EVENT_STOP;
     }
 
-    _onAccountsChanged(am) {
+    _onAccountsChanged() {
         let hasAccounts = this._accountsMonitor.visibleAccounts.length > 0;
         this._roomListRevealer.reveal_child = hasAccounts;
     }
@@ -343,7 +344,7 @@ var MainWindow = GObject.registerClass({
             });
     }
 
-    _onRoomsLoaded(mgr) {
+    _onRoomsLoaded() {
         if (this.active_room)
             return;
 
