@@ -1,13 +1,11 @@
-const Gdk = imports.gi.Gdk;
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+/* exported RoomList RoomListHeader RoomRow */
+
+const { Gdk, Gio, GLib, GObject, Gtk } = imports.gi;
 const Mainloop = imports.mainloop;
 const Tp = imports.gi.TelepathyGLib;
 
-const {AccountsMonitor} = imports.accountsMonitor;
-const {RoomManager} = imports.roomManager;
+const { AccountsMonitor } = imports.accountsMonitor;
+const { RoomManager } = imports.roomManager;
 
 const MIN_SPINNER_TIME = 1000000;   //in microsecond
 
@@ -102,7 +100,7 @@ var RoomRow = GObject.registerClass({
             return [nPending, nPending];
 
         let highlights = pending.filter(m => {
-            let [text, ] = m.to_text();
+            let [text] = m.to_text();
             return this._room.should_highlight_message(m.sender.alias, text);
         });
         return [nPending, highlights.length];
@@ -284,11 +282,11 @@ var RoomListHeader = GObject.registerClass({
 
         let parent;
         do
-          parent = this.get_parent();
+            parent = this.get_parent();
         while (parent && !(parent instanceof Gtk.ListBox));
 
         if (parent)
-          parent.invalidate_sort();
+            parent.invalidate_sort();
 
         let accessibleName = _("Network %s has an error").format(this._account.display_name);
         this.get_accessible().set_name(accessibleName);
@@ -345,7 +343,7 @@ var RoomListHeader = GObject.registerClass({
         this._spinner.active = (child == 'connecting');
         this._popoverTitle.visible = !isAuth;
 
-        if(this._spinner.active)
+        if (this._spinner.active)
             this._spinnerActivationTime = GLib.get_monotonic_time();
 
         this._popoverTitle.use_markup = isError;
@@ -481,11 +479,15 @@ class RoomList extends Gtk.ListBox {
                   this._selectRoomAtIndex(param.get_int32() - 1);
               } },
             { name: 'next-pending-room',
-              handler: () => { this._moveSelectionFull(Gtk.DirectionType.DOWN,
-                                                       row => row.hasPending); } },
+              handler: () => {
+                  this._moveSelectionFull(Gtk.DirectionType.DOWN,
+                                          row => row.hasPending);
+              } },
             { name: 'previous-pending-room',
-              handler: () => { this._moveSelectionFull(Gtk.DirectionType.UP,
-                                                       row => row.hasPending); } }
+              handler: () => {
+                  this._moveSelectionFull(Gtk.DirectionType.UP,
+                                          row => row.hasPending);
+              } }
         ];
         actions.forEach(a => {
             app.lookup_action(a.name).connect('activate', a.handler);
@@ -529,7 +531,7 @@ class RoomList extends Gtk.ListBox {
         this._moveSelectionFull(direction, () => { return true; });
     }
 
-    _moveSelectionFull(direction, testFunction){
+    _moveSelectionFull(direction, testFunction) {
         let current = this.get_selected_row();
         if (!current)
             return;
