@@ -1,14 +1,12 @@
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
-const Pango = imports.gi.Pango;
+/* exported RoomStack */
+
+const { Gio, GLib, GObject, Gtk, Pango } = imports.gi;
 const Tp = imports.gi.TelepathyGLib;
 
-const {AccountsMonitor} = imports.accountsMonitor;
-const {ChatView} = imports.chatView;
-const {EntryArea} = imports.entryArea;
-const {RoomManager} = imports.roomManager;
+const { AccountsMonitor } = imports.accountsMonitor;
+const { ChatView } = imports.chatView;
+const { EntryArea } = imports.entryArea;
+const { RoomManager } = imports.roomManager;
 
 var RoomStack = GObject.registerClass({
     Properties: {
@@ -85,7 +83,7 @@ var RoomStack = GObject.registerClass({
     }
 });
 
-var SavePasswordConfirmationBar = GObject.registerClass(
+const SavePasswordConfirmationBar = GObject.registerClass(
 class SavePasswordConfirmationBar extends Gtk.Revealer {
     _init(room) {
         this._room = room;
@@ -110,7 +108,7 @@ class SavePasswordConfirmationBar extends Gtk.Revealer {
     }
 
     _createWidget() {
-        this._infoBar = new Gtk.InfoBar({ show_close_button: true })
+        this._infoBar = new Gtk.InfoBar({ show_close_button: true });
         this.add(this._infoBar);
 
         let target = new GLib.Variant('o', this._room.account.object_path);
@@ -146,14 +144,14 @@ class SavePasswordConfirmationBar extends Gtk.Revealer {
     }
 });
 
-var ChatPlaceholder = GObject.registerClass(
+const ChatPlaceholder = GObject.registerClass(
 class ChatPlaceholder extends Gtk.Overlay {
     _init(sizeGroup) {
         this._accountsMonitor = AccountsMonitor.getDefault();
 
         let image = new Gtk.Image({ icon_name: 'org.gnome.Polari-symbolic',
-                                      pixel_size: 96, halign: Gtk.Align.END,
-                                      margin_end: 14 });
+                                    pixel_size: 96, halign: Gtk.Align.END,
+                                    margin_end: 14 });
 
         let title = new Gtk.Label({ use_markup: true, halign: Gtk.Align.START,
                                     margin_start: 14 });
@@ -182,7 +180,7 @@ class ChatPlaceholder extends Gtk.Overlay {
     }
 });
 
-var RoomView = GObject.registerClass(
+const RoomView = GObject.registerClass(
 class RoomView extends Gtk.Overlay {
     _init(room, sizeGroup) {
         super._init({ name: `RoomView ${room.display_name}` });
@@ -206,13 +204,13 @@ class RoomView extends Gtk.Overlay {
         sizeGroup.add_widget(this._entryArea);
 
         this._view.connect('text-dropped', (view, text) => {
-           this._entryArea.pasteText(text, text.split('\n').length);
+            this._entryArea.pasteText(text, text.split('\n').length);
         });
         this._view.connect('image-dropped', (view, image) => {
-           this._entryArea.pasteImage(image);
+            this._entryArea.pasteImage(image);
         });
         this._view.connect('file-dropped', (view, file) => {
-           this._entryArea.pasteFile(file);
+            this._entryArea.pasteFile(file);
         });
 
         this.show_all();
