@@ -1,13 +1,12 @@
-const Gdk = imports.gi.Gdk;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+/* exported ServerRoomManager ServerRoomList */
+
+const { Gdk, GLib, GObject, Gtk } = imports.gi;
 const Mainloop = imports.mainloop;
 const Signals = imports.signals;
 const Tp = imports.gi.TelepathyGLib;
 
-const {AccountsMonitor} = imports.accountsMonitor;
-const {RoomManager} = imports.roomManager;
+const { AccountsMonitor } = imports.accountsMonitor;
+const { RoomManager } = imports.roomManager;
 const Utils = imports.utils;
 
 const MS_PER_IDLE = 10; // max time spend in idle
@@ -63,7 +62,7 @@ var ServerRoomManager = class {
         roomList.init_async(GLib.PRIORITY_DEFAULT, null, (o, res) => {
             try {
                 roomList.init_finish(res);
-            } catch(e) {
+            } catch (e) {
                 this._roomLists.delete(account);
                 return;
             }
@@ -106,8 +105,8 @@ const RoomListColumn = {
 };
 
 function _strBaseEqual(str1, str2) {
-    return str1.localeCompare(str2, {}, { sensitivity: 'base'}) == 0;
-};
+    return str1.localeCompare(str2, {}, { sensitivity: 'base' }) == 0;
+}
 
 var ServerRoomList = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/server-room-list.ui',
@@ -120,8 +119,7 @@ var ServerRoomList = GObject.registerClass({
                                                         'can-join',
                                                         'can-join',
                                                         GObject.ParamFlags.READABLE,
-                                                       false)
-    },
+                                                        false) },
 }, class ServerRoomList extends Gtk.Box {
     _init(params) {
         this._account = null;
@@ -165,12 +163,12 @@ var ServerRoomList = GObject.registerClass({
             if (this._filterEntry.text.trim().length == 0)
                 return;
 
-            let [selected, model, iter] = this._list.get_selection().get_selected();
+            let [selected, model_, iter] = this._list.get_selection().get_selected();
             if (selected)
                 this._toggleChecked(this._list.model.get_path(iter));
         });
 
-        this._list.connect('row-activated', (view, path, column) => {
+        this._list.connect('row-activated', (view, path, _column) => {
             this._toggleChecked(path);
         });
 
@@ -272,7 +270,7 @@ var ServerRoomList = GObject.registerClass({
     }
 
     _clearList() {
-        let [valid, iter] = this._store.get_iter_first();
+        let [valid_, iter] = this._store.get_iter_first();
         if (this._isCustomRoomItem(iter))
             return;
         this._store.move_before(this._customRoomItem, iter);
@@ -332,11 +330,9 @@ var ServerRoomList = GObject.registerClass({
                 let checked = !sensitive;
                 let count = '%d'.format(roomInfo.get_members_count(null));
 
+                let { CHECKED, NAME, COUNT, SENSITIVE } = RoomListColumn;
                 let iter = store.insert_with_valuesv(-1,
-                                                     [RoomListColumn.CHECKED,
-                                                      RoomListColumn.NAME,
-                                                      RoomListColumn.COUNT,
-                                                      RoomListColumn.SENSITIVE],
+                                                     [CHECKED, NAME, COUNT, SENSITIVE],
                                                      [checked, name, count, sensitive]);
                 store.move_before(iter, this._customRoomItem);
 
@@ -361,7 +357,7 @@ var ServerRoomList = GObject.registerClass({
 
     _toggleChecked(path) {
         let childPath = this._list.model.convert_path_to_child_path(path);
-        let [valid, iter] = this._store.get_iter(childPath);
+        let [valid_, iter] = this._store.get_iter(childPath);
         if (!this._store.get_value(iter, RoomListColumn.SENSITIVE))
             return;
         let checked = this._store.get_value(iter, RoomListColumn.CHECKED);
