@@ -1,6 +1,6 @@
-const Gdk = imports.gi.Gdk;
-const Gtk = imports.gi.Gtk;
-const Pango = imports.gi.Pango;
+/* exported TabCompletion */
+
+const { Gdk, Gtk, Pango } = imports.gi;
 
 const IrcParser = imports.ircParser;
 
@@ -61,10 +61,10 @@ var TabCompletion = class {
         let layout = this._entry.get_layout();
         let layoutIndex = this._entry.text_index_to_layout_index(this._startPos);
         let wordPos = layout.index_to_pos(layoutIndex);
-        let [layoutX,] = this._entry.get_layout_offsets();
+        let [layoutX] = this._entry.get_layout_offsets();
 
         let allocation = this._entry.get_allocation();
-        let [ret, x, y] = win.get_origin();
+        let [ret_, x, y] = win.get_origin();
         x += allocation.x + Math.min((layoutX + wordPos.x) / Pango.SCALE,
                                      allocation.width - width);
         y += allocation.y - height;
@@ -222,7 +222,7 @@ var TabCompletion = class {
         this._insertCompletion(this._getRowCompletion(visibleRows[0]));
         if (visibleRows.length > 1) {
             this._list.select_row(visibleRows[0]);
-            this._showPopup()
+            this._showPopup();
         }
     }
 
