@@ -1,11 +1,10 @@
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Polari = imports.gi.Polari;
+/* exported TelepathyClient */
+
+const { Gio, GLib, GObject, Polari } = imports.gi;
 const Tp = imports.gi.TelepathyGLib;
 
-const {AccountsMonitor} = imports.accountsMonitor;
-const {RoomManager} = imports.roomManager;
+const { AccountsMonitor } = imports.accountsMonitor;
+const { RoomManager } = imports.roomManager;
 const Utils = imports.utils;
 
 const SASLAuthenticationIface = '<node> \
@@ -52,7 +51,7 @@ class SASLAuthHandler {
                                         this._onProxyReady.bind(this));
     }
 
-    _onProxyReady(proxy) {
+    _onProxyReady() {
         this._proxy.connectSignal('SASLStatusChanged',
                                   this._onSASLStatusChanged.bind(this));
 
@@ -75,7 +74,7 @@ class SASLAuthHandler {
         let statusString = (Object.keys(SASLStatus))[status];
         debug('Auth status for server "%s": %s'.format(name, statusString));
 
-        switch(status) {
+        switch (status) {
             case SASLStatus.NOT_STARTED:
             case SASLStatus.IN_PROGRESS:
             case SASLStatus.CLIENT_ACCEPTED:
@@ -103,7 +102,7 @@ class SASLAuthHandler {
                                            'available', '', null);
         });
     }
-};
+}
 
 var TelepathyClient = GObject.registerClass(
 class TelepathyClient extends Tp.BaseClient {
@@ -242,7 +241,7 @@ class TelepathyClient extends Tp.BaseClient {
         account.request_presence_async(presence, status, msg, (o, res) => {
             try {
                 account.request_presence_finish(res);
-            } catch(e) {
+            } catch (e) {
                 log('Connection failed: ' + e.message);
             }
         });
@@ -283,7 +282,7 @@ class TelepathyClient extends Tp.BaseClient {
                 let channel = null;
                 try {
                     channel = req.ensure_and_observe_channel_finish(res);
-                } catch(e) {
+                } catch (e) {
                     debug('Failed to ensure channel: ' + e.message);
                 }
 
@@ -316,7 +315,7 @@ class TelepathyClient extends Tp.BaseClient {
                 room.send_identify_message_async(command, username, password, (r, res) => {
                     try {
                         r.send_identify_message_finish(res);
-                    } catch(e) {
+                    } catch (e) {
                         log('Failed to send identify message: ' + e.message);
                     }
                     this._connectRooms(account);
@@ -333,7 +332,7 @@ class TelepathyClient extends Tp.BaseClient {
             (c, res) => {
                 try {
                     c.send_message_finish(res);
-                } catch(e) {
+                } catch (e) {
                     log('Failed to send message: ' + e.message);
                 }
             });
@@ -377,7 +376,7 @@ class TelepathyClient extends Tp.BaseClient {
     }
 
     _onQueryActivated(action, parameter) {
-        let [accountPath, channelName, message, time] = parameter.deep_unpack();
+        let [accountPath, channelName, message, time_] = parameter.deep_unpack();
         let account = this._accountsMonitor.lookupAccount(accountPath);
 
         if (!account || !account.enabled)
@@ -414,7 +413,7 @@ class TelepathyClient extends Tp.BaseClient {
         room.channel.leave_async(reason, message, (c, res) => {
             try {
                 c.leave_finish(res);
-            } catch(e) {
+            } catch (e) {
                 log('Failed to leave channel: ' + e.message);
             }
         });
@@ -466,7 +465,8 @@ class TelepathyClient extends Tp.BaseClient {
     }
 
     _isAuthChannel(channel) {
-        return channel.channel_type == Tp.IFACE_CHANNEL_TYPE_SERVER_AUTHENTICATION;
+        let channelType = channel.get_channel_type();
+        return channelType == Tp.IFACE_CHANNEL_TYPE_SERVER_AUTHENTICATION;
     }
 
     _processRequest(context, connection, channels, processChannel) {
@@ -492,18 +492,18 @@ class TelepathyClient extends Tp.BaseClient {
         context.accept();
     }
 
-    vfunc_observe_channels(account, connection, channels,
-                                     op, requests, context) {
+    vfunc_observe_channels(...args) {
+        let [account_, connection, channels, op_, requests_, context] = args;
         this._processRequest(context, connection, channels, channel => {
             if (this._isAuthChannel(channel))
                 return;
 
             if (channel.has_interface(Tp.IFACE_CHANNEL_INTERFACE_GROUP)) {
-                let [invited, , , ,] = channel.group_get_local_pending_contact_info(channel.group_self_contact);
+                let [invited] = channel.group_get_local_pending_contact_info(channel.group_self_contact);
                 if (invited)
-                  // this is an invitation - only add it in handleChannel
-                  // if accepted
-                  return;
+                    // this is an invitation - only add it in handleChannel
+                    // if accepted
+                    return;
             }
 
             channel.connect('message-received',
@@ -515,20 +515,20 @@ class TelepathyClient extends Tp.BaseClient {
         });
     }
 
-    vfunc_handle_channels(account, connection, channels,
-                                    satisfied, userTime, context) {
-        let [present, ] = Tp.user_action_time_should_present(userTime);
+    vfunc_handle_channels(...args) {
+        let [account_, connection, channels, satisfied_, time, context] = args;
+        let [present] = Tp.user_action_time_should_present(time);
 
         this._processRequest(context, connection, channels, channel => {
             if (this._isAuthChannel(channel)) {
-                let authHandler = new SASLAuthHandler(channel);
+                new SASLAuthHandler(channel);
                 return;
             }
 
             if (present)
                 this._app.activate();
 
-            this._roomManager.ensureRoomForChannel(channel, userTime);
+            this._roomManager.ensureRoomForChannel(channel, time);
             //channel.join_async('', null);
         });
     }
@@ -594,7 +594,7 @@ class TelepathyClient extends Tp.BaseClient {
     }
 
     _onMessageReceived(channel, msg) {
-        let [id, ] = msg.get_pending_message_id();
+        let [id] = msg.get_pending_message_id();
         let room = this._roomManager.lookupRoomByChannel(channel);
 
         // Rooms are removed instantly when the user requests it, but closing
@@ -603,7 +603,7 @@ class TelepathyClient extends Tp.BaseClient {
         if (!room || this._app.isRoomFocused(room))
             return;
 
-        let [text, ] = msg.to_text();
+        let [text] = msg.to_text();
         let nick = msg.sender.alias;
         if (!room.should_highlight_message(nick, text))
             return;
