@@ -1,10 +1,7 @@
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+/* exported UserList UserListPopover UserDetails UserPopover */
+
+const { Gio, GLib, GObject, Gtk, Pango, Polari } = imports.gi;
 const Mainloop = imports.mainloop;
-const Pango = imports.gi.Pango;
-const Polari = imports.gi.Polari;
 const Tp = imports.gi.TelepathyGLib;
 
 const READWRITE = GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE;
@@ -110,10 +107,10 @@ var UserDetails = GObject.registerClass({
                                                         READWRITE,
                                                         false),
                   'notifications-enabled': GObject.ParamSpec.boolean('notifications-enabled',
-                                                             'notifications-enabled',
-                                                             'notifications-enabled',
-                                                             READWRITE,
-                                                             false)},
+                                                                     'notifications-enabled',
+                                                                     'notifications-enabled',
+                                                                     READWRITE,
+                                                                     false) },
 }, class UserDetails extends Gtk.Frame {
     _init(params = {}) {
         let user = params.user;
@@ -255,7 +252,7 @@ var UserDetails = GObject.registerClass({
                         "%d months ago", months).format(months);
     }
 
-    _onContactInfoReady(c, res) {
+    _onContactInfoReady() {
         this._initialDetailsLoaded = true;
 
         let fn, last;
@@ -295,10 +292,10 @@ var UserDetails = GObject.registerClass({
         let action = app.lookup_action('message-user');
         let time = Gtk.get_current_event().get_time();
         action.activate(GLib.Variant.new('(sssu)',
-                                         [ account.get_object_path(),
-                                           this._user.alias,
-                                           '',
-                                           time ]));
+                                         [account.get_object_path(),
+                                          this._user.alias,
+                                          '',
+                                          time]));
     }
 
     _updateButtonVisibility() {
@@ -379,7 +376,7 @@ var UserPopover = GObject.registerClass({
             this._userTracker.unwatchRoomStatus(this._room, this._roomStatusChangedId);
         this._roomStatusChangedId =
             this._userTracker.watchRoomStatus(this._room, this._basenick,
-                                              this._onNickStatusChanged.bind(this));
+                                              this._onStatusChanged.bind(this));
 
         if (this._globalStatusChangedId > 0)
             this._userTracker.disconnect(this._globalStatusChangedId);
@@ -420,10 +417,6 @@ var UserPopover = GObject.registerClass({
 
     _updateDetailsContact() {
         this._userDetails.user = this._userTracker.lookupContact(this._nickname);
-     }
-
-    _onNickStatusChanged(baseNick, status) {
-        this._onStatusChanged();
     }
 });
 
@@ -571,8 +564,6 @@ class UserList extends Gtk.ScrolledWindow {
                            this._updateContentHeight.bind(this));
 
         this._list.set_selection_mode(Gtk.SelectionMode.NONE);
-        /* see https://bugzilla.gnome.org/show_bug.cgi?id=725403 */
-        //this._list.set_header_func(this._updateHeader.bind(this));
         this._filter = '';
         this._list.set_filter_func(this._filterRows.bind(this));
         this._list.set_sort_func(this._sort.bind(this));
@@ -597,11 +588,6 @@ class UserList extends Gtk.ScrolledWindow {
               handler: this._onMemberRemoved.bind(this) },
             { name: 'member-joined',
               handler: this._onMemberJoined.bind(this) },
-            /*
-            // see https://bugzilla.gnome.org/show_bug.cgi?id=725403
-            { name: 'members-changed',
-              handler: this._onMembersChanged.bind(this) },
-            */
             { name: 'notify::channel',
               handler: this._onChannelChanged.bind(this) }
         ];
@@ -666,10 +652,6 @@ class UserList extends Gtk.ScrolledWindow {
         this._addMember(member);
     }
 
-    _onMembersChanged(room) {
-        this._counterLabel.label = this.numRows.toString();
-    }
-
     _onChannelChanged(room) {
         this._list.foreach(w => { w.destroy(); });
         this._rows.clear();
@@ -714,32 +696,4 @@ class UserList extends Gtk.ScrolledWindow {
         row.setFilter(this._filter);
         return row.shouldShow();
     }
-
-    _updateHeader(row, before) {
-        if (before) {
-            row.set_header(null);
-            return;
-        }
-
-        if (row.get_header())
-            return;
-
-        if (!this._room.channel)
-            return;
-
-        let box = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
-                                margin_start: 6,
-                                margin_end: 6,
-                                spacing: 6 });
-        box.add(new Gtk.Label({ label: '<b>' + _("All") + '</b>',
-                                use_markup: true,
-                                hexpand: true,
-                                halign: Gtk.Align.START }));
-        this._counterLabel = new Gtk.Label({ label: this.numRows.toString(),
-                                             halign: Gtk.Align.END });
-        box.add(this._counterLabel);
-        box.show_all();
-
-        row.set_header(box);
-    }
 });
