@@ -1,3 +1,7 @@
+/* exported isFlatpakSandbox getTpEventTime findUrls findChannels openURL
+            storeAccountPassword storeIdentifyPassword
+            lookupAccountPassword lookupIdentifyPassword
+            updateTerms gpaste imgurPaste */
 /*
  * Copyright (c) 2011 Red Hat, Inc.
  *
@@ -20,12 +24,7 @@
  *
  */
 
-const Gdk = imports.gi.Gdk;
-const Gio = imports.gi.Gio;
-const GLib = imports.gi.GLib;
-const Gtk = imports.gi.Gtk;
-const Secret = imports.gi.Secret;
-const Soup = imports.gi.Soup;
+const { Gdk, Gio, GLib, Gtk, Secret, Soup }  = imports.gi;
 const Tp = imports.gi.TelepathyGLib;
 
 const AppNotifications = imports.appNotifications;
@@ -83,7 +82,7 @@ const _urlRegexp = new RegExp(
         ')' +
     ')', 'gi');
 
-const _channelRegexp = new RegExp('(^| )#([\\w\\+\\.-]+)','g');
+const _channelRegexp = new RegExp('(^| )#([\\w\\+\\.-]+)', 'g');
 
 let _gpasteExpire = undefined;
 
@@ -98,7 +97,7 @@ function isFlatpakSandbox() {
 function getTpEventTime() {
     let time = Gtk.get_current_event_time ();
     if (time == 0)
-      return GLib.MAXUINT32;
+        return GLib.MAXUINT32;
     return Tp.user_action_time_from_x11 (time);
 }
 
@@ -119,7 +118,7 @@ function _storePassword(schema, label, account, password, callback) {
         try {
             let success = Secret.password_store_finish(res);
             callback(success);
-        } catch(e) {
+        } catch (e) {
             log('Failed to store password for account "%s": %s'.format(
                 account.display_name, e.message));
             callback(false);
@@ -141,7 +140,7 @@ function _lookupPassword(schema, account, callback) {
         try {
             let password = Secret.password_lookup_finish(res);
             callback(password);
-        } catch(e) {
+        } catch (e) {
             log('Failed to lookup password for account "%s": %s'.format(
                 account.display_name, e.message));
             callback(null);
@@ -177,10 +176,10 @@ function openURL(url, timestamp) {
     let app = Gio.Application.get_default();
     try {
         if (app.active_window)
-            Gtk.show_uri_on_window (app.active_window, url, timestamp)
+            Gtk.show_uri_on_window (app.active_window, url, timestamp);
         else
             Gtk.show_uri (Gdk.Screen.get_default(), url, timestamp);
-    } catch(e) {
+    } catch (e) {
         let n = new AppNotifications.SimpleOutput(_("Failed to open link"));
         app.notificationQueue.addNotification(n);
         debug("failed to open %s: %s".format(url, e.message));
@@ -214,7 +213,7 @@ function _getGpasteExpire(callback) {
         let info = {};
         try {
             info = JSON.parse(message.response_body.data);
-        } catch(e) {
+        } catch (e) {
             log(e.message);
         }
 
@@ -263,7 +262,7 @@ function gpaste(text, title, callback) {
         let info = {};
         try {
             info = JSON.parse(message.response_body.data);
-        } catch(e) {
+        } catch (e) {
             log(e.message);
         }
         if (info.result && info.result.id)
@@ -300,7 +299,7 @@ function imgurPaste(pixbuf, title, callback) {
         let info = {};
         try {
             info = JSON.parse(message.response_body.data);
-        } catch(e) {
+        } catch (e) {
             log(e.message);
         }
         if (info.success)
